import { Method } from 'axios';
import { useEffect, useState } from 'react';
import { API } from '../controllers';
import { Status } from '../requests';

export const useAxios = (
  method: Method,
  url: string,
  payload?: any,
  headers?: any
) => {
  const [response, setResponse] = useState<any>(null);
  const [status, setStatus] = useState<Status['name']>('idle');
  const [error, setError] = useState<any>(null);

  useEffect(() => {
    setStatus('loading');

    (async () => {
      try {
        const { data } = await API(method, url, payload, headers);

        setStatus('success');
        setResponse(data);
      } catch(err: any) {
        setStatus('failed');
        setError(err.response.data);
      }
    })();
  }, [method, url, payload, headers]);

  return [response, status, error];
};
